@@ -40,11 +40,7 @@ VALUE rb_cRenderHTML;
 VALUE rb_cRenderHTML_TOC;
 VALUE rb_mSmartyPants;
 
-#ifdef HAVE_RUBY_ENCODING_H
-#define buf2str(t) ((t) ? redcarpet_str_new((const char*)(t)->data, (t)->size, opt->active_enc) : Qnil)
-#else
-#define buf2str(t) ((t) ? redcarpet_str_new((const char*)(t)->data, (t)->size, NULL) : Qnil)
-#endif
+#define buf2str(t) ((t) ? rb_enc_str_new((const char*)(t)->data, (t)->size, opt->active_enc) : Qnil)
 
 static void
 rndr_blockcode(struct buf *ob, const struct buf *text, const struct buf *lang, void *opaque)
@@ -171,6 +167,12 @@ rndr_underline(struct buf *ob, const struct buf *text, void *opaque)
 	SPAN_CALLBACK("underline", 1, buf2str(text));
 }
 
+static int
+rndr_highlight(struct buf *ob, const struct buf *text, void *opaque)
+{
+	SPAN_CALLBACK("highlight", 1, buf2str(text));
+}
+
 static int
 rndr_image(struct buf *ob, const struct buf *link, const struct buf *title, const struct buf *alt, void *opaque)
 {
@@ -279,6 +281,7 @@ static struct sd_callbacks rb_redcarpet_callbacks = {
 	rndr_double_emphasis,
 	rndr_emphasis,
 	rndr_underline,
+	rndr_highlight,
 	rndr_image,
 	rndr_linebreak,
 	rndr_link,
@@ -312,6 +315,7 @@ static const char *rb_redcarpet_method_names[] = {
 	"double_emphasis",
 	"emphasis",
 	"underline",
+	"highlight",
 	"image",
 	"linebreak",
 	"link",
@@ -456,7 +460,7 @@ static VALUE rb_redcarpet_smartypants_render(VALUE self, VALUE text)
 	output_buf = bufnew(128);
 
 	sdhtml_smartypants(output_buf, (const uint8_t*)RSTRING_PTR(text), RSTRING_LEN(text));
-	result = redcarpet_str_new((const char*)output_buf->data, output_buf->size, rb_enc_get(text));
+	result = rb_enc_str_new((const char*)output_buf->data, output_buf->size, rb_enc_get(text));
 
 	bufrelease(output_buf);
 	return result;
